#!/bin/ksh
#
# $Header: runuf1.sh 25-oct -2001.15:56:04 mpoess Exp $
#
# runuf1.sh
#
# Copyright (c) 1999, 2001, Oracle Corporation. All rights reserved.
#
# NAME
# runuf1.sh - <one-line expansion of the name>
#
# DESCRIPTION
# runuf1.sh -l [<path name for reports>] -u [<uid/passwd>]
# -p [<program>] <run_id> <scale factor> <pair number>
# <parallelism>
# USAGE
# To execute UF1.
#
. $KIT_DIR/env
O=${ORACLE_HOME}
UPDATE_DIR=${KIT_DIR}/update
SCRIPT_DIR=${UPDATE_DIR}/scripts
UTILS_DIR=${KIT_DIR}/utils
LOG_DIR=${UPDATE_DIR}/log
GTIME=${SCRIPT_DIR}/gtime
SF=${SCALE_FACTOR}
PAR_HINT=192
LOGPATH=.
PASSWD=${DATABASE_USER}

START=`$GTIME`


if [ $# -lt 1 ];
then
echo runuf1.sh setnum
exit 1
fi
SETNUM=$1
i=1
PID=""


sqlplus /NOLOG << !
connect $PASSWD;
set timing on
set serveroutput on
set echo on

alter session set parallel_degree_policy='MANUAL';

drop directory data_dir;
create directory data_dir as '/ff_updates/3TB';

drop table temp_l_et;
create table temp_l_et(
	l_orderkey number ,
	l_partkey number ,
	l_suppkey number ,
	l_linenumber number ,
	l_quantity number ,
	l_extendedprice number ,
	l_discount number ,
	l_tax number ,
	l_returnflag char(1) ,
	l_linestatus char(1) ,
	l_shipdate date ,
	l_commitdate date ,
	l_receiptdate date ,
	l_shipinstruct char(25) ,
	l_shipmode char(10) ,
	l_comment varchar(44)
)
organization external (
	type ORACLE_LOADER
	default directory data_dir
	access parameters
	(
		records delimited by newline
		nobadfile
		nologfile
		fields terminated by '|'
		missing field values are null
	)
	location (
		'lineitem.tbl.u${SETNUM}'
))
reject limit unlimited parallel ${PAR_HINT};


drop table temp_o_et;

create table temp_o_et(
	o_orderkey number ,
	o_custkey number ,
	o_orderstatus char(1) ,
	o_totalprice number ,
	o_orderdate date ,
	o_orderpriority char(15) ,
	o_clerk char(15) ,
	o_shippriority number ,
	o_comment varchar(79)
)
organization external (
	type ORACLE_LOADER
	default directory data_dir
	access parameters
	(
		records delimited by newline
		nobadfile
		nologfile
		fields terminated by '|'
		missing field values are null
	)
	location (
	'orders.tbl.u${SETNUM}'
))
reject limit unlimited parallel  ${PAR_HINT};

alter session force parallel dml parallel (degree ${PAR_HINT});
alter session set isolation_level = serializable;
alter session set optimizer_index_cost_adj=25;

insert into orders
select
o_orderdate ,
o_orderkey ,
o_custkey ,
o_orderpriority ,
o_shippriority ,
o_clerk ,
o_orderstatus ,
o_totalprice ,
o_comment
from temp_o_et;

insert into lineitem
select
l_shipdate ,
l_orderkey ,
l_discount ,
l_extendedprice ,
l_suppkey ,
l_quantity ,
l_returnflag ,
l_partkey ,
l_linestatus ,
l_tax ,
l_commitdate ,
l_receiptdate ,
l_shipmode ,
l_linenumber ,
l_shipinstruct ,
l_comment
from temp_l_et;


commit;
drop table temp_l_et;
drop table temp_o_et;

exit;
!

END=`$GTIME`


echo ""
echo "Update Function 1 Set $SETNUM done!"
echo "Elapsed Time is `echo $END - $START | bc`"
echo ""
